==> photo-0.6.tgz: photo-0.6/php/prj.php <==
<?php
 /***********************************************************
  䴩ͺ\
  ΨӳBz@M檺{
  submit1=w   w\
  process=d   dߥ\
  process=Wǹ showXsƽs榡
  process=sW   usWƮw\
  process=R   R峹\
  process=ק   iJק峹sҦ
  process=update uק峹
 ************************************************************/
 require("user.php");
 require($configfile);
 require("dbconfig.php");
 require("procpic.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="prj.php";
  //TableXSOѼ
 $tabout="border=1";
  //d߳浧ƪY
  //C@
 $PGNUM=20;
 // Primary Key	
 $PKEY="aid";
 $RETADD="listmain.php?$user";
 /******N_ର@*****/
 function nl22br($txt)
 {
    $ntxt="";
    $stok=strtok($txt,"\n");
    while (!($stok === FALSE))
    {
	$stok=trim($stok);
	if (strlen($stok)) $ntxt=$ntxt."\n".$stok;
	else $ntxt=$ntxt."<br>\n";
	$stok=strtok("\n");
    }
    return(substr($ntxt,1));//hh\n
 }
 if (strlen(trim($key))==0)
 	$OBJ=$ptab;
 else  $OBJ=$key;
 require("auth.php");  //αM׼h{
 $DAYTIME=date("Y~mdH:i:s");
 //show insert and search form
 if (strcmp($submit1,"w")==0) 
 {
  //TJM[ӵqշ_Ϊ
    $txt=nl22br($txt);
    $abst=nl22br($abst);
	 /*****	XnͪM *******/
   $QUERY="select ptab,pname,ctlfile,target from main where ptab = '$ptab'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow!=1){
        echo "MƬdߧ $numrow ơAO $QUERY !";
        exit;
   }
   	$PARAW=db_fetch_row($result,0); //Ū@M峹O
	$PARAW[2]=trim($PARAW[2]);
        $CONF=$CDIR.$PARAW[2].".cfg";
	/* $fn1=$DESTDIR.trim($ARAW[0])."1234.html"; remove by tjm for test */
	  if (file_exists($CONF)&&(!is_link($CONF)))
 	  	$OUT1=join( "", file( $CONF ) );
	  else
	  {
		echo "ɮ $CONF sbI<br>\n";
	  }
	
	  /****** ഫ *****/
	  $txt=procpic($txt,$ptab,1);
	  $abst=procpic($abst,$ptab,1);
	  $OUT1=str_replace("%title%",$title,$OUT1); //title
	  $OUT1=str_replace("%author%",$author,$OUT1); //author
	  $OUT1=str_replace("%pubtime%",$pubtime,$OUT1); //ptime
	  $OUT1=str_replace("%abst%",$abst,$OUT1); //abst
	  $OUT1=str_replace("%txt%",$txt,$OUT1); //txt
	  $OUT1=str_replace("%email%",$email,$OUT1); //email
	  $OUT1=str_replace("%username%",$PHP_AUTH_USER,$OUT1); //usernam
	  $ofn1=trim($ARAW[0])."567.html";
	  $OUT1=str_replace("%prev%",$ofn1,$OUT1); //previous file
	  echo $OUT1;
	 exit;
 }
 
 if ((strcmp($process,"Wǹ")==0)||(strcmp($process,"d")==0)) 
 {
   $QUERY="select ptab,pname from main where ptab='$key'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
	echo "MƬd߿~AO $QUERY !";
	exit;
   }
   $numrow=db_NumRows($result);  
   if ($numrow>1){
	echo "MƬdߧ $numrow ơAO $QUERY !";
	exit;
   }
   if ($numrow==0){
	echo "MƬdߧ䤣ơAO $QUERY !";
	exit;
   }
   $ARAW=db_fetch_row($result,0); //Ū@O
   /****}榡 ******/
   if (strcmp($process,"Wǹ")==0)
   	$OUT=join( "", file( "inprj.cfg" ) );
   else
   	$OUT=join( "", file( "search.cfg" ) );
   session_register("SUSER","SMAIL");//o username P email
   $OUT=str_replace("%CNAME",$ARAW[1],$OUT);
   $OUT=str_replace("%PRJ","<input type=\"hidden\" name=\"ptab\" value=\"$key\">",$OUT);
   $DAYTIME=date("Y.m.d");
   $OUT=str_replace("%TIME",$DAYTIME,$OUT);
   $OUT=str_replace("%user%",$user,$OUT);
   $OUT=str_replace("%SUSER%",$SUSER,$OUT);
   $OUT=str_replace("%SMAIL%",$SMAIL,$OUT);
   echo $OUT;
   exit;
 }
 if (get_magic_quotes_gpc()==0)
  {
	$title=rtrim($title).' ';
	$title=addslashes($title);
	$author=rtrim($author).' ';
	$author=addslashes($author);
	$abst=addslashes($abst);
	$txt=addslashes($txt);
	$email=addslashes($email);
	
  }
  //TJM[ӵqշ_Ϊ
    $txt=nl22br($txt);
    $txt=rtrim($txt).' ';
    $abst=nl22br($abst);
    $abst=rtrim($abst).' ';
 if (strcmp($process,"sW")==0) // insert
 {
   session_register("SUSER","SMAIL");// username P email
   $SUSER=$author;
   $SMAIL=$email;
  //Bzupload
   $ptab=$_REQUEST["ptab"];
   $QUERY="select ptab,pname,ctlfile,target from main where ptab = '$ptab'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow==0){
        echo "MƬdߧ䤣ơAO $QUERY !";
        exit;
   }
   $AROW=db_fetch_row($result,0);
   db_freeresult($result);
   /**** s ******/
   $QUERY="select coalesce(max($ptab.aid)+1,1) from $ptab ";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow==0){
        echo "WɮɦWpXDO $QUERY !";
        exit;
   }
   $UARAW=db_fetch_row($result,0); //Ū@O
   //o̧אּɦW
   $fpad=strtolower(strrchr($_FILES['userfile']['name'],"."));
   $fname=trim($UARAW[0]).$fpad;
   $UPLOADDIR=$upload_dir."$AROW[3]/";
   $UPLOADSDIR=$upload_dir."$AROW[3]/small/";
   //$UPLOADDIR=$upload_dir."$ptab/";
   //$UPLOADSDIR=$upload_dir."$ptab/small/";
   if (!is_dir($UPLOADDIR))
        {
            echo "$UPLOADDIR sbI<br>\n";
            if (!mkdir($UPLOADDIR,0755)) echo "إ$UPLOADDIR ؿ!<br>\n";
            else echo "إ$UPLOADDIR ؿ\!<br>\n";
            if (!mkdir($UPLOADSDIR,0755)) echo "إ$UPLOADSDIR ؿ!<br>\n";
            else echo "إ$UPLOADSDIR ؿ\!<br>\n";
        }
   if (strlen(trim($fname))==0)
	die ("fname SơI");
   else
	{
   		$FILENAME=$UPLOADDIR.trim($fname);
   		$SFILENAME=$UPLOADSDIR.trim($fname);
   		$FILEN=trim($fname);
	}
   if (!copy($userfile,$FILENAME))
	{
        	echo "WǥѡALk $userfile h $FILENAME ";
        	exit;
	}
   //ͤp
    if (strpos($SFILENAME,".jpg")!==false)
    {
    	$pif=ImageCreateFromJPEG($FILENAME);
	$pix=GetImageSize($FILENAME);
  	$wid=$pix[0];
  	$h=$pix[1];
        if ($wid>=$h) //
        {
               $SSX=$SX;
               $SSY=$SY;
	}
        else //
        {
               $SSX=$SY;
               $SSY=$SX;
        }
	$pif1=ImageCreate($SSX,$SSY);
	 ImageCopyResized($pif1,$pif,0,0,0,0,$SSX,$SSY,$wid,$h);
	ImageDestroy($pif);
	ImageJpeg($pif1,$SFILENAME);
	ImageDestroy($pif1);
    } elseif (strpos($SFILENAME,".png")!==false)
    {
    	$pif=ImageCreateFromPNG($FILENAME);
	$pix=GetImageSize($FILENAME);
  	$wid=$pix[0];
  	$h=$pix[1];
        if ($wid>=$h) //
        {
               $SSX=$SX;
               $SSY=$SY;
	}
        else //
        {
               $SSX=$SY;
               $SSY=$SX;
        }
	$pif1=ImageCreate($SSX,$SSY);
	 ImageCopyResized($pif1,$pif,0,0,0,0,$SSX,$SSY,$wid,$h);
	ImageDestroy($pif);
	ImagePNG($pif1,$SFILENAME);
	ImageDestroy($pif1);
    }
    else
         unset($pif);
  } //BzuploadAsW
  //INSERTOAoӫOdn|yۮeD
  $INSERT="insert into $ptab values (coalesce(max($ptab.aid)+1,1), '$title','$author','$pubtime','$abst','$txt','$fname','$email','$PHP_AUTH_USER','$REMOTE_ADDR','$DAYTIME');"; 
  //DELETEO
 $LIMIT=stripslashes($LIMIT);
 $DELETE="delete from $ptab  where ".$LIMIT;
 if (strcmp($process,"sW")==0) // insert
 {
   /******** ˬdOO ****/
   $result=db_exec($db_conn,$INSERT);
   if (!$result){
	echo "ƷsW~AO $INSERT !";
	exit;
   }
	echo "<a href=\"$RETADD\">J\IB}I</a><br>\n";
	echo "<a href=\"{$PHP_SELF}?user={$user}&key={$OBJ}&process=Wǹ\">~JI</a>\n";
 	exit;
 }
 /******** Update ****************/
  $UPDATE="update $ptab set title='$title',author='$author',pubtime='$pubtime', abst='$abst', txt='$txt',email='$email',username='$PHP_AUTH_USER',ip='$REMOTE_ADDR',modtime='$DAYTIME' where ".$LIMIT;
 if (strcmp($process,"update")==0) // update
 {
   $result=db_exec($db_conn,$UPDATE);
   if (!$result){
        echo "ƷsW~AO $UPDATE !";
        exit;
   }
        echo "<a href=\"$RETADD\">s\IB}I</a>\n";
        exit;
 }

 /*****  R ********/
 if (strcmp($process,"R")==0) //DELETE 
 {
   /****Rɮ ****/
   $SEARCH="select filename,title,author,pubtime,username from $ptab where ".$LIMIT;
   $result=db_exec($db_conn,$SEARCH);
   if (!$result){
	echo "ƧR~AO $SEARCH !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   /*****Bzv******/
   $ARAW[4]=trim($ARAW[4]);
   if (strcasecmp($PHP_AUTH_USER,$ARAW[4])!=0&& !in_array($PHP_AUTH_USER,$MANAGER))
   {
	die("$PHP_AUTH_USER AO $ARAW[4] ΤO޲z SRv");
   }
   //$UPLOADDIR=$upload_dir."$ptab/";
   //$UPLOADSDIR=$upload_dir."$ptab/small/";
   $QUERY="select target from main where ptab='$ptab'";
   $res=db_exec($db_conn,$QUERY);
   if (!$result) {
     echo "Error!!<br>\n";
     exit;
   }
   $AROW=db_fetch_row($res,0);
   $UPLOADDIR=$upload_dir."$AROW[0]/";
   $UPLOADSDIR=$upload_dir."$AROW[0]/small/";
   db_freeresult($res);
   $FILENAME=$UPLOADDIR.trim($ARAW[0]);
   $SFILENAME=$UPLOADSDIR.trim($ARAW[0]);
   if (is_file($FILENAME)) unlink($FILENAME);
   if (is_file($SFILENAME)) unlink($SFILENAME);
   db_freeresult($result);

   /****ABz****/
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
	echo "ƧR~AO $DELETE !";
	exit;
   }
	echo "<a href=\"$RETADD\">R\IB}I</a>\n";
        exit;
 }
 /*****  ק ********/
 $EDIT="select title,author,email,pubtime,abst,txt,username from $ptab where ".$LIMIT;
 if (strcmp($process,"ק")==0) //EDIT 
 {
   $result=db_exec($db_conn,$EDIT);
   if (!$result){
	echo "ƭק~AO $EDIT !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   /*****Bzv******/
   $ARAW[6]=trim($ARAW[6]);
   if (strcasecmp($PHP_AUTH_USER,$ARAW[6])!=0&& !in_array($PHP_AUTH_USER,$MANAGER))
   {
	die("$PHP_AUTH_USER AO $ARAW[6] ΤO޲z SRv");
   }
   // add by tjm to replace KnPe
   $ARAW[4]=str_replace("<br>","",$ARAW[4]);
   $ARAW[5]=str_replace("<br>","",$ARAW[5]);
   /****} ******/
   $fcfg=fopen("editprj.cfg","r");
   $cnt=0;
   $PAT="%DATA";
   while (!feof($fcfg)) 
      {
         $temp=fgets($fcfg,256);
 	 if (strstr($temp,$PAT))
         {
		$temp=str_replace($PAT,$ARAW[$cnt],$temp);
		$cnt=$cnt+1;
	 } elseif (strstr($temp,"%LIMIT"))
	 {
		$temp=str_replace("%LIMIT","<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">",$temp);
	 }
	 elseif (strstr($temp,"%PRJ"))
	 {
		$temp=str_replace("%PRJ","<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">",$temp);
	 }
	 elseif (strstr($temp,"%user%"))
	 {
		$temp=str_replace("%user%",$user,$temp);
	 }
	 echo $temp;
      }
   fclose($fcfg);
        exit;
 }
?>

==> photo-0.62.tgz: photo-0.62/php/prj.php <==
<?php
 /***********************************************************
  䴩ͺ\
  ΨӳBz@M檺{
  submit1=w   w\
  process=d   dߥ\
  process=Wǹ showXsƽs榡
  process=sW   usWƮw\
  process=R   R峹\
  process=ק   iJק峹sҦ
  process=update uק峹
 ************************************************************/
 require("user.php");
 require($configfile);
 require("dbconfig.php");
 require("procpic.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="prj.php";
  //TableXSOѼ
 $tabout="border=1";
  //d߳浧ƪY
  //C@
 $PGNUM=20;
 // Primary Key	
 $PKEY="aid";
 $RETADD="listmain.php?$user";
 /******N_ର@*****/
 function nl22br($txt)
 {
    $ntxt="";
    $stok=strtok($txt,"\n");
    while (!($stok === FALSE))
    {
	$stok=trim($stok);
	if (strlen($stok)) $ntxt=$ntxt."\n".$stok;
	else $ntxt=$ntxt."<br>\n";
	$stok=strtok("\n");
    }
    return(substr($ntxt,1));//hh\n
 }
 if (strlen(trim($key))==0)
 	$OBJ=$ptab;
 else  $OBJ=$key;
 require("auth.php");  //αM׼h{
 $DAYTIME=date("Y~mdH:i:s");
 //show insert and search form
 if (strcmp($submit1,"w")==0) 
 {
  //TJM[ӵqշ_Ϊ
    $txt=nl22br($txt);
    $abst=nl22br($abst);
	 /*****	XnͪM *******/
   $QUERY="select ptab,pname,ctlfile,target from main where ptab = '$ptab'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow!=1){
        echo "MƬdߧ $numrow ơAO $QUERY !";
        exit;
   }
   	$PARAW=db_fetch_row($result,0); //Ū@M峹O
	$PARAW[2]=trim($PARAW[2]);
        $CONF=$CDIR.$PARAW[2].".cfg";
	/* $fn1=$DESTDIR.trim($ARAW[0])."1234.html"; remove by tjm for test */
	  if (file_exists($CONF)&&(!is_link($CONF)))
 	  	$OUT1=join( "", file( $CONF ) );
	  else
	  {
		echo "ɮ $CONF sbI<br>\n";
	  }
	
	  /****** ഫ *****/
	  $txt=procpic($txt,$ptab,1);
	  $abst=procpic($abst,$ptab,1);
	  $OUT1=str_replace("%title%",$title,$OUT1); //title
	  $OUT1=str_replace("%author%",$author,$OUT1); //author
	  $OUT1=str_replace("%pubtime%",$pubtime,$OUT1); //ptime
	  $OUT1=str_replace("%abst%",$abst,$OUT1); //abst
	  $OUT1=str_replace("%txt%",$txt,$OUT1); //txt
	  $OUT1=str_replace("%email%",$email,$OUT1); //email
	  $OUT1=str_replace("%username%",$PHP_AUTH_USER,$OUT1); //usernam
	  $ofn1=trim($ARAW[0])."567.html";
	  $OUT1=str_replace("%prev%",$ofn1,$OUT1); //previous file
	  echo $OUT1;
	 exit;
 }
 
 if ((strcmp($process,"Wǹ")==0)||(strcmp($process,"d")==0)) 
 {
   $QUERY="select ptab,pname from main where ptab='$key'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
	echo "MƬd߿~AO $QUERY !";
	exit;
   }
   $numrow=db_NumRows($result);  
   if ($numrow>1){
	echo "MƬdߧ $numrow ơAO $QUERY !";
	exit;
   }
   if ($numrow==0){
	echo "MƬdߧ䤣ơAO $QUERY !";
	exit;
   }
   $ARAW=db_fetch_row($result,0); //Ū@O
   /****}榡 ******/
   if (strcmp($process,"Wǹ")==0)
   	$OUT=join( "", file( "inprj.cfg" ) );
   else
   	$OUT=join( "", file( "search.cfg" ) );
   session_register("SUSER","SMAIL");//o username P email
   $OUT=str_replace("%CNAME",$ARAW[1],$OUT);
   $OUT=str_replace("%PRJ","<input type=\"hidden\" name=\"ptab\" value=\"$key\">",$OUT);
   $DAYTIME=date("Y.m.d");
   $OUT=str_replace("%TIME",$DAYTIME,$OUT);
   $OUT=str_replace("%user%",$user,$OUT);
   $OUT=str_replace("%SUSER%",$SUSER,$OUT);
   $OUT=str_replace("%SMAIL%",$SMAIL,$OUT);
   echo $OUT;
   exit;
 }
 if (get_magic_quotes_gpc()==0)
  {
	$title=rtrim($title).' ';
	$title=addslashes($title);
	$author=rtrim($author).' ';
	$author=addslashes($author);
	$abst=addslashes($abst);
	$txt=addslashes($txt);
	$email=addslashes($email);
	
  }
  //TJM[ӵqշ_Ϊ
    $txt=nl22br($txt);
    $txt=rtrim($txt).' ';
    $abst=nl22br($abst);
    $abst=rtrim($abst).' ';
 if (strcmp($process,"sW")==0) // insert
 {
   session_register("SUSER","SMAIL");// username P email
   $SUSER=$author;
   $SMAIL=$email;
  //Bzupload
   $ptab=$_REQUEST["ptab"];
   $QUERY="select ptab,pname,ctlfile,target from main where ptab = '$ptab'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow==0){
        echo "MƬdߧ䤣ơAO $QUERY !";
        exit;
   }
   $AROW=db_fetch_row($result,0);
   db_freeresult($result);
   /**** s ******/
   $QUERY="select coalesce(max($ptab.aid)+1,1) from $ptab ";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow==0){
        echo "WɮɦWpXDO $QUERY !";
        exit;
   }
   $UARAW=db_fetch_row($result,0); //Ū@O
   //o̧אּɦW
   $fpad=strtolower(strrchr($_FILES['userfile']['name'],"."));
   $fname=trim($UARAW[0]).$fpad;
   $UPLOADDIR=$upload_dir."$AROW[3]/";
   $UPLOADSDIR=$upload_dir."$AROW[3]/small/";
   //$UPLOADDIR=$upload_dir."$ptab/";
   //$UPLOADSDIR=$upload_dir."$ptab/small/";
   if (!is_dir($UPLOADDIR))
        {
            echo "$UPLOADDIR sbI<br>\n";
            if (!mkdir($UPLOADDIR,0755)) echo "إ$UPLOADDIR ؿ!<br>\n";
            else echo "إ$UPLOADDIR ؿ\!<br>\n";
            if (!mkdir($UPLOADSDIR,0755)) echo "إ$UPLOADSDIR ؿ!<br>\n";
            else echo "إ$UPLOADSDIR ؿ\!<br>\n";
        }
   if (strlen(trim($fname))==0)
	die ("fname SơI");
   else
	{
   		$FILENAME=$UPLOADDIR.trim($fname);
   		$SFILENAME=$UPLOADSDIR.trim($fname);
   		$FILEN=trim($fname);
	}
   //if (!copy($userfile,$FILENAME))
   if (!copy($_FILES['userfile']['tmp_name'],$FILENAME))
	{
        	echo "WǥѡALk {$_FILES['userfile']['tmp_name']} h $FILENAME ";
        	exit;
	}
   //ͤp
    if (strpos($SFILENAME,".jpg")!==false)
    {
    	$pif=ImageCreateFromJPEG($FILENAME);
	$pix=GetImageSize($FILENAME);
  	$wid=$pix[0];
  	$h=$pix[1];
	if (($wid/$h)>1.4 || ($h/$wid)>1.4) //зǩ榡BzL
	{
        	if ($wid>=$h) //
        	{
               		$SSX=$wid;
               		$SSY=(int) ($wid*768/1024);
		}
        	else //
        	{
              		$SSX=(int) ($h*768/1024);
               		$SSY=$h;
        	}
	 	$pif1=imagecreatetruecolor($SSX,$SSY);
         	imagecopy($pif1,$pif,($SSX-$wid)/2,($SSY-$h)/2,0,0,$wid,$h);
		ImageJpeg($pif1,$FILENAME);
		ImageDestroy($pif1);
	}
        if ($wid>=$h) //
        {
               $SSX=$SX;
               $SSY=$SY;
	}
        else //
        {
               $SSX=$SY;
               $SSY=$SX;
        }
	 $pif1=imagecreatetruecolor($SSX,$SSY);
         imagecopyresampled($pif1,$pif,0,0,0,0,$SSX,$SSY,$wid,$h);
	//$pif1=ImageCreate($SSX,$SSY);
	 //ImageCopyResized($pif1,$pif,0,0,0,0,$SSX,$SSY,$wid,$h);
	ImageDestroy($pif);
	ImageJpeg($pif1,$SFILENAME);
	ImageDestroy($pif1);
    } elseif (strpos($SFILENAME,".png")!==false)
    {
    	$pif=ImageCreateFromPNG($FILENAME);
	$pix=GetImageSize($FILENAME);
  	$wid=$pix[0];
  	$h=$pix[1];
        if ($wid>=$h) //
        {
               $SSX=$SX;
               $SSY=$SY;
	}
        else //
        {
               $SSX=$SY;
               $SSY=$SX;
        }
	$pif1=ImageCreate($SSX,$SSY);
	 ImageCopyResized($pif1,$pif,0,0,0,0,$SSX,$SSY,$wid,$h);
	ImageDestroy($pif);
	ImagePNG($pif1,$SFILENAME);
	ImageDestroy($pif1);
    }
    else
         unset($pif);
  } //BzuploadAsW
  //INSERTOAoӫOdn|yۮeD
  $INSERT="insert into $ptab values (coalesce(max($ptab.aid)+1,1), '$title','$author','$pubtime','$abst','$txt','$fname','$email','$PHP_AUTH_USER','$REMOTE_ADDR','$DAYTIME');"; 
  //DELETEO
 $LIMIT=stripslashes($LIMIT);
 $DELETE="delete from $ptab  where ".$LIMIT;
 if (strcmp($process,"sW")==0) // insert
 {
   /******** ˬdOO ****/
   $result=db_exec($db_conn,$INSERT);
   if (!$result){
	echo "ƷsW~AO $INSERT !";
	exit;
   }
	echo "<a href=\"$RETADD\">J\IB}I</a><br>\n";
	echo "<a href=\"{$PHP_SELF}?user={$user}&key={$OBJ}&process=Wǹ\">~JI</a>\n";
 	exit;
 }
 /******** Update ****************/
  $UPDATE="update $ptab set title='$title',author='$author',pubtime='$pubtime', abst='$abst', txt='$txt',email='$email',username='$PHP_AUTH_USER',ip='$REMOTE_ADDR',modtime='$DAYTIME' where ".$LIMIT;
 if (strcmp($process,"update")==0) // update
 {
   $result=db_exec($db_conn,$UPDATE);
   if (!$result){
        echo "ƷsW~AO $UPDATE !";
        exit;
   }
        echo "<a href=\"$RETADD\">s\IB}I</a>\n";
        exit;
 }

 /*****  R ********/
 if (strcmp($process,"R")==0) //DELETE 
 {
   /****Rɮ ****/
   $SEARCH="select filename,title,author,pubtime,username from $ptab where ".$LIMIT;
   $result=db_exec($db_conn,$SEARCH);
   if (!$result){
	echo "ƧR~AO $SEARCH !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   /*****Bzv******/
   $ARAW[4]=trim($ARAW[4]);
   if (strcasecmp($PHP_AUTH_USER,$ARAW[4])!=0&& !in_array($PHP_AUTH_USER,$MANAGER))
   {
	die("$PHP_AUTH_USER AO $ARAW[4] ΤO޲z SRv");
   }
   //$UPLOADDIR=$upload_dir."$ptab/";
   //$UPLOADSDIR=$upload_dir."$ptab/small/";
   $QUERY="select target from main where ptab='$ptab'";
   $res=db_exec($db_conn,$QUERY);
   if (!$result) {
     echo "Error!!<br>\n";
     exit;
   }
   $AROW=db_fetch_row($res,0);
   $UPLOADDIR=$upload_dir."$AROW[0]/";
   $UPLOADSDIR=$upload_dir."$AROW[0]/small/";
   db_freeresult($res);
   $FILENAME=$UPLOADDIR.trim($ARAW[0]);
   $SFILENAME=$UPLOADSDIR.trim($ARAW[0]);
   if (is_file($FILENAME)) unlink($FILENAME);
   if (is_file($SFILENAME)) unlink($SFILENAME);
   db_freeresult($result);

   /****ABz****/
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
	echo "ƧR~AO $DELETE !";
	exit;
   }
	echo "<a href=\"$RETADD\">R\IB}I</a>\n";
        exit;
 }
 /*****  ק ********/
 $EDIT="select title,author,email,pubtime,abst,txt,username from $ptab where ".$LIMIT;
 if (strcmp($process,"ק")==0) //EDIT 
 {
   $result=db_exec($db_conn,$EDIT);
   if (!$result){
	echo "ƭק~AO $EDIT !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   /*****Bzv******/
   $ARAW[6]=trim($ARAW[6]);
   if (strcasecmp($PHP_AUTH_USER,$ARAW[6])!=0&& !in_array($PHP_AUTH_USER,$MANAGER))
   {
	die("$PHP_AUTH_USER AO $ARAW[6] ΤO޲z Sק諸v");
   }
   // add by tjm to replace KnPe
   $ARAW[4]=str_replace("<br>","",$ARAW[4]);
   $ARAW[5]=str_replace("<br>","",$ARAW[5]);
   /****} ******/
   $fcfg=fopen("editprj.cfg","r");
   $cnt=0;
   $PAT="%DATA";
   while (!feof($fcfg)) 
      {
         $temp=fgets($fcfg,256);
 	 if (strstr($temp,$PAT))
         {
		$temp=str_replace($PAT,$ARAW[$cnt],$temp);
		$cnt=$cnt+1;
	 } elseif (strstr($temp,"%LIMIT"))
	 {
		$temp=str_replace("%LIMIT","<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">",$temp);
	 }
	 elseif (strstr($temp,"%PRJ"))
	 {
		$temp=str_replace("%PRJ","<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">",$temp);
	 }
	 elseif (strstr($temp,"%user%"))
	 {
		$temp=str_replace("%user%",$user,$temp);
	 }
	 echo $temp;
      }
   fclose($fcfg);
        exit;
 }
?>
